@@ -1,5 +1,3 @@
-from collections import OrderedDict
-
 import grpc
 from django.core.exceptions import ValidationError
 from django.db.models.query import QuerySet
@@ -141,15 +139,6 @@ class GenericService(services.Service):
             return None
         return self.paginator.paginate_queryset(queryset, self.context, view=self)
 
-    def get_paginated_response(self, data):
-        """
-        Return a paginated style `Response` object for the given output data.
-        """
-        assert self.paginator is not None
-        # can not use next line because it return a Django Response object so whe have to override it ourselve
-        # return self.paginator.get_paginated_response(data)
-        return OrderedDict([("count", self.paginator.page.paginator.count), ("results", data)])
-
 
 class CreateService(mixins.CreateModelMixin, GenericService):
     """
